package
module
Version:
v0.1.1
Opens a new window with list of versions in this module.
Published: Apr 22, 2019
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
README
¶
sitemap
Easily generate sitemaps.
Documentation
¶
type Site struct {
URL string
}
Site represents a single page or URL.
Sitemap represents a single sitemap.
New creates a new sitemap.
Add adds a site to the sitemap.
Text creates a list of your URLs in text format.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.